Config

Struct Config 

pub struct Config {
    pub authority: Pubkey,
    pub expired_funds_account: Pubkey,
    pub num_epochs_valid: u64,
    pub max_validator_commission_bps: u16,
    pub go_live_epoch: u64,
    pub bump: u8,
}

Fields

authority: Pubkey

Account with authority over this PDA.

expired_funds_account: Pubkey

We want to expire funds after some time so that validators can be refunded the rent. Expired funds will get transferred to this account.

num_epochs_valid: u64

Specifies the number of epochs a merkle root is valid for before expiring.

max_validator_commission_bps: u16

The maximum commission a validator can set on their distribution account.

go_live_epoch: u64

The epoch where lamports are transferred to the priority fee distribution account.

bump: u8

The bump used to generate this account

Implementations

Source

impl Config

pub const SEED: &'static [u8] = b"CONFIG_ACCOUNT"

pub const SIZE: usize = 96usize

pub fn validate(&self) -> Result<()>