PriorityFeeDistributionAccount

Struct PriorityFeeDistributionAccount 

pub struct PriorityFeeDistributionAccount {
    pub validator_vote_account: Pubkey,
    pub merkle_root_upload_authority: Pubkey,
    pub merkle_root: Option<MerkleRoot>,
    pub epoch_created_at: u64,
    pub validator_commission_bps: u16,
    pub expires_at: u64,
    pub total_lamports_transferred: u64,
    pub bump: u8,
}
The account that validators send priority fees to

Fields

validator_vote_account: Pubkey

The validator’s vote account, also the recipient of remaining lamports after upon closing this account.

merkle_root_upload_authority: Pubkey

The only account authorized to upload a merkle-root for this account.

merkle_root: Option<MerkleRoot>

The merkle root used to verify user claims from this account.

epoch_created_at: u64

Epoch for which this account was created.

validator_commission_bps: u16

The commission basis points this validator charges.

expires_at: u64

The epoch (upto and including) that tip funds can be claimed.

total_lamports_transferred: u64

The total lamports transferred to this account.

bump: u8

The bump used to generate this account

Implementations

Source

impl PriorityFeeDistributionAccount

pub const SEED: &'static [u8] = b"PF_DISTRIBUTION_ACCOUNT"

pub const SIZE: usize = 176usize

pub fn validate(&self) -> Result<()>

pub fn claim_expired(from: AccountInfo<'_>, to: AccountInfo<'_>) -> Result<u64>

pub fn claim( from: AccountInfo<'_>, to: AccountInfo<'_>, amount: u64, ) -> Result<()>

pub fn increment_total_lamports_transferred( &mut self, amount: u64, ) -> Result<()>